==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/checkerrorsdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "checkerrorsdialog.h"

#include <qlayout.h>
#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>

#include <klocale.h>


using namespace SubtitleComposer;

CheckErrorsDialog::CheckErrorsDialog( QWidget* parent ):
	TargetableTextsActionDialog( i18n( "Check Errors" ), parent )
{
	QGroupBox* errorsGroupBox = createGroupBox( i18n( "Errors to check" ) );

	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
	{
		if ( (0x1 << id) & SubtitleLine::SecondaryErrors )
			m_errorsCheckBox[id] = 0;
		else
		{
			m_errorsCheckBox[id] = new QCheckBox( errorsGroupBox );
			m_errorsCheckBox[id]->setText( SubtitleLine::errorText( (SubtitleLine::ErrorID)id ) );
			m_errorsCheckBox[id]->setChecked( true );
		}
	}

	QPushButton* selectAllButton = new QPushButton( errorsGroupBox );
	selectAllButton->setText( i18n( "Select All" ) );
	QPushButton* selectNoneButton = new QPushButton( errorsGroupBox );
	selectNoneButton->setText( i18n( "Select None" ) );

	connect( selectAllButton, SIGNAL( clicked() ), this, SLOT( selectAll() ) );
	connect( selectNoneButton, SIGNAL( clicked() ), this, SLOT( selectNone() ) );


	QGroupBox* otherGroupBox = createGroupBox( i18n( "Miscellaneous" ) );

	m_clearOtherErrorsCheckBox = new QCheckBox( otherGroupBox );
	m_clearOtherErrorsCheckBox->setText( i18n( "Clear other errors" ) );
	m_clearOtherErrorsCheckBox->setChecked( true );

	m_clearMarksCheckBox = new QCheckBox( otherGroupBox );
	m_clearMarksCheckBox->setText( i18n( "Clear user marks" ) );


	createTextsTargetGroupBox();

	m_textsTargetGroupBox->setTitle( i18n( "Target subtitle (for checks involving text)" ) );


	createLinesTargetGroupBox();

	QGridLayout* errorsLayout = createLayout( errorsGroupBox );

	int row = 0;
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
	{
		if ( m_errorsCheckBox[id] )
		{
			errorsLayout->addMultiCellWidget( m_errorsCheckBox[id], row, row, 0, 2 );
			row++;
		}
	}

	errorsLayout->addWidget( selectAllButton, row, 1 );
	errorsLayout->addWidget( selectNoneButton, row, 2 );

	QGridLayout* otherLayout = createLayout( otherGroupBox );
	otherLayout->addWidget( m_clearOtherErrorsCheckBox, 0, 0 );
	otherLayout->addWidget( m_clearMarksCheckBox, 1, 0 );
}

int CheckErrorsDialog::errorFlagsToCheck()
{
	int errorFlags = 0;
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
		if ( m_errorsCheckBox[id] && m_errorsCheckBox[id]->isChecked() )
			errorFlags |= SubtitleLine::errorFlag( (SubtitleLine::ErrorID)id );

	switch ( textTarget() )
	{
		case SubtitleLine::Primary:
		{
			return errorFlags;
		}
		case SubtitleLine::Secondary:
		{
			int secondaryErrorFlags = (errorFlags & SubtitleLine::PrimaryErrors) << 1;
			errorFlags = errorFlags & ~SubtitleLine::PrimaryErrors;
			return errorFlags | secondaryErrorFlags;
		}
		case SubtitleLine::Both:
		default:
		{
			int secondaryErrorFlags = (errorFlags & SubtitleLine::PrimaryErrors) << 1;
			return errorFlags | secondaryErrorFlags;
		}
	}
}

bool CheckErrorsDialog::clearOtherErrors()
{
	return m_clearOtherErrorsCheckBox->isChecked();
}

bool CheckErrorsDialog::clearMarks()
{
	return m_clearMarksCheckBox->isChecked();
}

void CheckErrorsDialog::selectAll()
{
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
		if ( m_errorsCheckBox[id] )
			m_errorsCheckBox[id]->setChecked( true );
}

void CheckErrorsDialog::selectNone()
{
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
		if ( m_errorsCheckBox[id] )
			m_errorsCheckBox[id]->setChecked( false );
}

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/main/dialogs/checkerrorsdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "checkerrorsdialog.h"

#include <qlayout.h>
#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>

#include <klocale.h>


using namespace SubtitleComposer;

CheckErrorsDialog::CheckErrorsDialog( QWidget* parent ):
	TargetableTextsActionDialog( i18n( "Check Errors" ), parent )
{
	QGroupBox* errorsGroupBox = createGroupBox( i18n( "Errors to check" ) );

	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
	{
		if ( (0x1 << id) & SubtitleLine::SecondaryTextErrors )
			m_errorsCheckBox[id] = 0;
		else
		{
			m_errorsCheckBox[id] = new QCheckBox( errorsGroupBox );
			m_errorsCheckBox[id]->setText( SubtitleLine::errorText( (SubtitleLine::ErrorID)id ) );
			m_errorsCheckBox[id]->setChecked( true );
		}
	}

	QPushButton* selectAllButton = new QPushButton( errorsGroupBox );
	selectAllButton->setText( i18n( "Select All" ) );
	QPushButton* selectNoneButton = new QPushButton( errorsGroupBox );
	selectNoneButton->setText( i18n( "Select None" ) );

	connect( selectAllButton, SIGNAL( clicked() ), this, SLOT( selectAll() ) );
	connect( selectNoneButton, SIGNAL( clicked() ), this, SLOT( selectNone() ) );


	QGroupBox* otherGroupBox = createGroupBox( i18n( "Miscellaneous" ) );

	m_clearOtherErrorsCheckBox = new QCheckBox( otherGroupBox );
	m_clearOtherErrorsCheckBox->setText( i18n( "Clear other errors" ) );
	m_clearOtherErrorsCheckBox->setChecked( true );

	m_clearMarksCheckBox = new QCheckBox( otherGroupBox );
	m_clearMarksCheckBox->setText( i18n( "Clear user marks" ) );


	createTextsTargetGroupBox();

	m_textsTargetGroupBox->setTitle( i18n( "Target subtitle (for checks involving text)" ) );


	createLinesTargetGroupBox();

	QGridLayout* errorsLayout = createLayout( errorsGroupBox );

	int row = 0;
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
	{
		if ( m_errorsCheckBox[id] )
		{
			errorsLayout->addMultiCellWidget( m_errorsCheckBox[id], row, row, 0, 2 );
			row++;
		}
	}

	errorsLayout->addWidget( selectAllButton, row, 1 );
	errorsLayout->addWidget( selectNoneButton, row, 2 );

	QGridLayout* otherLayout = createLayout( otherGroupBox );
	otherLayout->addWidget( m_clearOtherErrorsCheckBox, 0, 0 );
	otherLayout->addWidget( m_clearMarksCheckBox, 1, 0 );
}

int CheckErrorsDialog::errorFlagsToCheck()
{
	int errorFlags = 0;
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
		if ( m_errorsCheckBox[id] && m_errorsCheckBox[id]->isChecked() )
			errorFlags |= SubtitleLine::errorFlag( (SubtitleLine::ErrorID)id );

	switch ( textTarget() )
	{
		case SubtitleLine::Primary:
		{
			return errorFlags;
		}
		case SubtitleLine::Secondary:
		{
			int secondaryErrorFlags = (errorFlags & SubtitleLine::PrimaryTextErrors) << 1;
			errorFlags = errorFlags & ~SubtitleLine::PrimaryTextErrors;
			return errorFlags | secondaryErrorFlags;
		}
		case SubtitleLine::Both:
		default:
		{
			int secondaryErrorFlags = (errorFlags & SubtitleLine::PrimaryTextErrors) << 1;
			return errorFlags | secondaryErrorFlags;
		}
	}
}

bool CheckErrorsDialog::clearOtherErrors()
{
	return m_clearOtherErrorsCheckBox->isChecked();
}

bool CheckErrorsDialog::clearMarks()
{
	return m_clearMarksCheckBox->isChecked();
}

void CheckErrorsDialog::selectAll()
{
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
		if ( m_errorsCheckBox[id] )
			m_errorsCheckBox[id]->setChecked( true );
}

void CheckErrorsDialog::selectNone()
{
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
		if ( m_errorsCheckBox[id] )
			m_errorsCheckBox[id]->setChecked( false );
}
